list_groups: List Groups

list_groupsR Documentation

List Groups

Description

List Groups

Usage

list_groups(filter, page_token = NULL, ...)

Arguments

filter

Named Vector. Required. Only one of the two: id or mine. id: Comma-separated list of YouTube group ID(s) to retrieve. mine: Set to TRUE to retrieve all groups owned by the authenticated user.

page_token

String. Optional. Identifies a specific page in the result set that should be returned.

...

Additional arguments passed to tubern_GET.

Value

named list

References

https://developers.google.com/youtube/analytics/reference/groups/list

Examples

## Not run: 
list_groups(filter = c(mine = TRUE))

## End(Not run)

tubern documentation built on April 12, 2026, 5:07 p.m.