| list_groups | R Documentation |
List Groups
list_groups(filter, page_token = NULL, ...)
filter |
Named Vector. Required. Only one of the two: id or mine. id: Comma-separated list of YouTube group ID(s) to retrieve. mine: Set to TRUE to retrieve all groups owned by the authenticated user. |
page_token |
String. Optional. Identifies a specific page in the result set that should be returned. |
... |
Additional arguments passed to |
named list
https://developers.google.com/youtube/analytics/reference/groups/list
## Not run:
list_groups(filter = c(mine = TRUE))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.